@@ -1,10 +1,13 @@
 import sys
 import unittest
 import warnings
+import shutil
+import pathlib
 
 import flask
 
 RESTX_PKG_NAME = "flask_restx"
+sys.path.append('../src')
 
 
 class MonkeyTest(unittest.TestCase):
@@ -46,7 +49,7 @@ class MonkeyTest(unittest.TestCase):
         self.assertIsNone(warn_register)
 
     def test_parse_rule(self):
-        from restx_monkey.werkzeug_routing import parse_rule
+        from src.restx_monkey.werkzeug_routing import parse_rule
         self.assertEqual(
             tuple(parse_rule("https://www.google.com/api/<int:version>/index.json?val=3")),
             ((None, None, 'https://www.google.com/api/'), ('int', None, 'version'), (None, None, '/index.json?val=3'))
@@ -128,6 +131,37 @@ class MonkeyTest(unittest.TestCase):
         tag_schema = list_parser.args[0].__schema__
         self.assertEqual(tag_schema["items"].get("pattern"), "^[-_a-zA-Z0-9]+$")
 
+    def test_swagger_replace(self):
+        import restx_monkey
+        from restx_monkey.swagger_ui import is_writable
+        self.assertFalse(is_writable("/root"))
+        self.assertTrue(is_writable(__file__))
+        # optimal scenario works
+        os_error = None
+        try:
+            restx_monkey.patch_restx(replace_parse_rule=True, fix_restx_api=True, update_swagger_ui=True)
+        except OSError as e:
+            os_error = e
+        self.assertIsNone(os_error)
+        # skip on no permission
+        os_error = None
+        try:
+            restx_monkey.swagger_ui.replace_static_swagger_files("/root/blabla")
+        except OSError as e:
+            os_error = e
+        self.assertIsNone(os_error)
+        os_error = None
+        # create missing `file` dir
+        tmp_static = pathlib.Path(__file__).parent / "__tmp_static__"
+        try:
+            tmp_static.mkdir(exist_ok=True)
+            restx_monkey.swagger_ui.replace_static_swagger_files(tmp_static)
+        except OSError as e:
+            os_error = e
+        finally:
+            shutil.rmtree(str(tmp_static), ignore_errors=True)
+        self.assertIsNone(os_error)
+
 
 if __name__ == '__main__':
     unittest.main()
